summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKian-Meng Ang <kianmeng.ang@gmail.com>2022-01-25 15:12:30 +0800
committerGitHub <noreply@github.com>2022-01-25 08:12:30 +0100
commit7128155b289b75dbfa50eb9179a15f2554d18daf (patch)
treed636c99f1469730be77a13540e707233e7ab0b0f
parent67a4f6f7f29897c38b460c86805e502dc36d1473 (diff)
downloadzope-interface-7128155b289b75dbfa50eb9179a15f2554d18daf.tar.gz
Fix typos (#251)
Co-authored-by: Michael Howitz <mh@gocept.com>
-rw-r--r--CHANGES.rst8
-rw-r--r--appveyor.yml1
-rw-r--r--docs/adapter.rst2
-rw-r--r--docs/api/components.rst2
-rw-r--r--docs/hacking.rst2
-rw-r--r--src/zope/interface/_zope_interface_coptimizations.c6
-rw-r--r--src/zope/interface/adapter.py2
-rw-r--r--src/zope/interface/declarations.py2
-rw-r--r--src/zope/interface/exceptions.py2
-rw-r--r--src/zope/interface/interfaces.py4
-rw-r--r--src/zope/interface/tests/test_interface.py2
-rw-r--r--src/zope/interface/tests/test_odd_declarations.py2
12 files changed, 18 insertions, 17 deletions
diff --git a/CHANGES.rst b/CHANGES.rst
index c650816..6aa9884 100644
--- a/CHANGES.rst
+++ b/CHANGES.rst
@@ -970,14 +970,14 @@ Bug Fixes
3.2.0 (2006-01-05)
==================
-- Corresponds to the verison of the zope.interface package shipped as part of
+- Corresponds to the version of the zope.interface package shipped as part of
the Zope 3.2.0 release.
3.1.0 (2005-10-03)
==================
-- Corresponds to the verison of the zope.interface package shipped as part of
+- Corresponds to the version of the zope.interface package shipped as part of
the Zope 3.1.0 release.
- Made attribute resolution order consistent with component lookup order,
@@ -990,7 +990,7 @@ Bug Fixes
3.0.1 (2005-07-27)
==================
-- Corresponds to the verison of the zope.interface package shipped as part of
+- Corresponds to the version of the zope.interface package shipped as part of
the Zope X3.0.1 release.
- Fix a bug reported by James Knight, which caused adapter registries
@@ -1000,5 +1000,5 @@ Bug Fixes
3.0.0 (2004-11-07)
==================
-- Corresponds to the verison of the zope.interface package shipped as part of
+- Corresponds to the version of the zope.interface package shipped as part of
the Zope X3.0.0 release.
diff --git a/appveyor.yml b/appveyor.yml
index 40460ef..b334494 100644
--- a/appveyor.yml
+++ b/appveyor.yml
@@ -48,6 +48,7 @@ build_script:
test_script:
- python -m unittest discover -s src
+
artifacts:
- path: 'dist\*.whl'
name: wheel
diff --git a/docs/adapter.rst b/docs/adapter.rst
index 0e8528b..c97b10c 100644
--- a/docs/adapter.rst
+++ b/docs/adapter.rst
@@ -130,7 +130,7 @@ If we register an object that provides ``IProvideBase``:
>>> registry.register([IRequireBase], IProvideBase, '', 'Base->Base')
-then that object will be prefered over ``O('Base->Child')``:
+then that object will be preferred over ``O('Base->Child')``:
.. doctest::
diff --git a/docs/api/components.rst b/docs/api/components.rst
index 204adc3..af6d0e9 100644
--- a/docs/api/components.rst
+++ b/docs/api/components.rst
@@ -53,7 +53,7 @@ All four share a common base interface.
.. autointerface:: zope.interface.interfaces.IRegistration
-* Utilties
+* Utilities
.. autointerface:: zope.interface.interfaces.IUtilityRegistration
.. autoclass:: zope.interface.registry.UtilityRegistration
diff --git a/docs/hacking.rst b/docs/hacking.rst
index a523225..7f5f586 100644
--- a/docs/hacking.rst
+++ b/docs/hacking.rst
@@ -56,7 +56,7 @@ environment:
$ /tmp/hack-zope.interface/bin/python setup.py develop
-Finally, run the tests using the build-in ``setuptools`` testrunner:
+Finally, run the tests using the built-in ``setuptools`` testrunner:
.. code-block:: sh
diff --git a/src/zope/interface/adapter.py b/src/zope/interface/adapter.py
index d85ed8d..9a542db 100644
--- a/src/zope/interface/adapter.py
+++ b/src/zope/interface/adapter.py
@@ -591,7 +591,7 @@ class BaseAdapterRegistry(object):
self.subscribe(*args)
# XXX hack to fake out twisted's use of a private api. We need to get them
- # to use the new registed method.
+ # to use the new registered method.
def get(self, _): # pragma: no cover
class XXXTwistedFakeOut:
selfImplied = {}
diff --git a/src/zope/interface/declarations.py b/src/zope/interface/declarations.py
index 9c06a16..59bd650 100644
--- a/src/zope/interface/declarations.py
+++ b/src/zope/interface/declarations.py
@@ -1294,7 +1294,7 @@ def _normalizeargs(sequence, output=None):
Normalization arguments might contain Declarions, tuples, or single
interfaces.
- Anything but individial interfaces or implements specs will be expanded.
+ Anything but individual interfaces or implements specs will be expanded.
"""
if output is None:
output = []
diff --git a/src/zope/interface/exceptions.py b/src/zope/interface/exceptions.py
index 2f3758b..47c351b 100644
--- a/src/zope/interface/exceptions.py
+++ b/src/zope/interface/exceptions.py
@@ -43,7 +43,7 @@ class _TargetInvalid(Invalid):
# of the two values in ``self.args``. *target* uses a marker object to
# distinguish "not given" from "given, but None", because the latter
# can be a value that gets passed to validation. For this reason, it must
- # always be the last argument (we detect absense by the ``IndexError``).
+ # always be the last argument (we detect absence by the ``IndexError``).
_IX_INTERFACE = 0
_IX_TARGET = 1
diff --git a/src/zope/interface/interfaces.py b/src/zope/interface/interfaces.py
index 2de22e7..66aecb9 100644
--- a/src/zope/interface/interfaces.py
+++ b/src/zope/interface/interfaces.py
@@ -1076,7 +1076,7 @@ class IObjectEvent(Interface):
"""An event related to an object.
The object that generated this event is not necessarily the object
- refered to by location.
+ referred to by location.
"""
object = Attribute("The subject of the event.")
@@ -1139,7 +1139,7 @@ class IComponentLookup(Interface):
"""Get subscribers
Subscribers are returned that provide the provided interface
- and that depend on and are comuted from the sequence of
+ and that depend on and are computed from the sequence of
required objects.
"""
diff --git a/src/zope/interface/tests/test_interface.py b/src/zope/interface/tests/test_interface.py
index 1b793cd..00c3597 100644
--- a/src/zope/interface/tests/test_interface.py
+++ b/src/zope/interface/tests/test_interface.py
@@ -563,7 +563,7 @@ class SpecificationTests(unittest.TestCase):
def test_multiple_inheritance_no_interfaces(self):
# If we extend an object that implements interfaces,
- # plus ane that doesn't, we do not interject `Interface`
+ # plus one that doesn't, we do not interject `Interface`
# early in the resolution order. It stays at the end,
# like it should.
# See https://github.com/zopefoundation/zope.interface/issues/8
diff --git a/src/zope/interface/tests/test_odd_declarations.py b/src/zope/interface/tests/test_odd_declarations.py
index 46e7675..bdede33 100644
--- a/src/zope/interface/tests/test_odd_declarations.py
+++ b/src/zope/interface/tests/test_odd_declarations.py
@@ -196,7 +196,7 @@ class Test(unittest.TestCase):
# class A(Odd):
# classProvides(I1)
# except TypeError:
- # pass # Sucess
+ # pass # Success
# self.assert_(False,
# "Shouldn't be able to use directlyProvides on odd class."
# )
diff --git a/src/zope/interface/_zope_interface_coptimizations.c b/src/zope/interface/_zope_interface_coptimizations.c
index 0b0713e..af52a0a 100644
--- a/src/zope/interface/_zope_interface_coptimizations.c
+++ b/src/zope/interface/_zope_interface_coptimizations.c
@@ -682,7 +682,7 @@ static PyTypeObject CPBType = {
/*
def __adapt__(self, obj):
"""Adapt an object to the reciever
"""
if self.providedBy(obj):
return obj
@@ -776,7 +776,7 @@ typedef struct {
static struct PyMethodDef ib_methods[] = {
{"__adapt__", (PyCFunction)__adapt__, METH_O,
- "Adapt an object to the reciever"},
+ "Adapt an object to the receiver"},
{NULL, NULL} /* sentinel */
};
@@ -1267,7 +1267,7 @@ _lookup(lookup *self,
}
/* If `required` is a lazy sequence, it could have arbitrary side-effects,
- such as clearing our caches. So we must not retreive the cache until
+ such as clearing our caches. So we must not retrieve the cache until
after resolving it. */
required = PySequence_Tuple(required);
if (required == NULL)
@@ -682,7 +682,7 @@ static PyTypeObject CPBType = {
/*
def __adapt__(self, obj):
- """Adapt an object to the reciever
+ """Adapt an object to the receiver
"""
if self.providedBy(obj):